Learn R Programming

baldur (version 0.0.4)

yeast: Spiked-in data set of reversibly oxidized cysteines

Description

A dataset containing quantification of reversibly oxidized cysteines using Progenesis. True positives cysteines spiked-in from yeast at two different concentrations and true negatives from Chlamydomonas reinhardtii with the same concentration in all samples. To identify true positives one can use stringr::str_detect(yeast$identifier, 'YEAST'). For details see berg2019evaluation;textualbaldur and if you use this dataset please cite the same paper.

Usage

yeast

Arguments

Format

A data frame with 2235 rows and 7 variables:

identifier

id column for features, true positives contains YEAST and true negatives contains Cre

ng50_1,ng50_2,ng50_3

Biological replicates with true positives spiked-in from 50 ng yeast cells

ng100_1,ng100_2,ng100_3

Biological replicates with true positives spiked-in from 100 ng yeast cells

References